@@ -1,15 +1,14 @@
 package App::tracepm;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-04-14'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
-use File::Temp qw(tempfile);
 use version;
 
 our %SPEC;
@@ -108,12 +107,18 @@ _
             summary => 'When recursing, exclude core modules',
             schema => ['bool'],
         },
+        trap_script_output => {
+            # XXX relevant only when method=trace or method=require
+            summary => 'Trap script output so it does not interfere '.
+                'with trace result',
+            schema => ['bool', is=>1],
+        },
         args => {
             summary => 'Script arguments',
             schema => ['array*' => of => 'str*'],
             req => 0,
             pos => 1,
-            greedy => 0,
+            greedy => 1,
         },
         perl_version => {
             summary => 'Perl version, defaults to current running version',
@@ -159,13 +164,15 @@ _
     },
 };
 sub tracepm {
+    require File::Temp;
+
     my %args = @_;
 
     my $script = $args{script};
     unless (defined $script) {
         my $eval = $args{eval};
         defined($eval) or die "Please specify input script or --eval (-e)\n";
-        my ($fh, $filename) = tempfile();
+        my ($fh, $filename) = File::Temp::tempfile();
         print $fh $eval;
         $script = $filename;
     }
@@ -196,23 +203,35 @@ sub tracepm {
     my @res;
     if ($method =~ /\A(fatpacker|require)\z/) {
 
-        my ($outfh, $outf) = tempfile();
+        my ($outfh, $outf) = File::Temp::tempfile();
 
+        my $routine;
         if ($method eq 'fatpacker') {
-            require App::FatPacker;
-            my $fp = App::FatPacker->new;
-            $fp->trace(
-                output => ">>$outf",
-                use    => $args{use},
-                args   => [$script, @{$args{args} // []}],
-            );
+            $routine = sub {
+                require App::FatPacker;
+                my $fp = App::FatPacker->new;
+                $fp->trace(
+                    output => ">>$outf",
+                    use    => $args{use},
+                    args   => [$script, @{$args{args} // []}],
+                );
+            };
         } else {
             # 'require' method
-            system($^X,
-                   "-MApp::tracepm::Tracer=$outf",
-                   (map {"-M$_"} @{$args{use} // []}),
-                   $script, @{$args{args} // []},
-               );
+            $routine = sub {
+                system($^X,
+                       "-MApp::tracepm::Tracer=$outf",
+                       (map {"-M$_"} @{$args{use} // []}),
+                       $script, @{$args{args} // []},
+                   );
+            };
+        }
+
+        if ($args{trap_script_output}) {
+            require Capture::Tiny;
+            Capture::Tiny::capture_merged($routine);
+        } else {
+            $routine->();
         }
 
         open my($fh), "<", $outf
@@ -377,12 +396,14 @@ App::tracepm - Trace dependencies of your Perl script
 
 =head1 VERSION
 
-This document describes version 0.14 of App::tracepm (from Perl distribution App-tracepm), released on 2015-01-03.
+This document describes version 0.15 of App::tracepm (from Perl distribution App-tracepm), released on 2015-04-14.
 
 =head1 SYNOPSIS
 
 This distribution provides command-line utility called L<tracepm>.
 
+=for Pod::Coverage ^()$
+
 =head1 FUNCTIONS
 
 
@@ -478,6 +499,10 @@ When recursing, exclude XS modules.
 
 Path to script file (script to be packed).
 
+=item * B<trap_script_output> => I<bool>
+
+Trap script output so it does not interfere with trace result.
+
 =item * B<use> => I<array[str]>
 
 Additional modules to "use".
@@ -502,7 +527,6 @@ element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
-=for Pod::Coverage ^()$
 
 =head1 HOMEPAGE
 
@@ -510,7 +534,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-tracep
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-tracepm>.
+Source repository is at L<https://github.com/perlancar/perl-App-tracepm>.
 
 =head1 BUGS
 
