@@ -1,6 +1,7 @@
 package App::tracepm::Tracer;
 
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-04-14'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 # saving CORE::GLOBAL::require doesn't work
 my $orig_require;
@@ -60,7 +61,7 @@ App::tracepm::Tracer - Trace module require to file
 
 =head1 VERSION
 
-This document describes version 0.14 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-01-03.
+This document describes version 0.15 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-04-14.
 
 =head1 HOMEPAGE
 
@@ -68,7 +69,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-tracep
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-tracepm>.
+Source repository is at L<https://github.com/perlancar/perl-App-tracepm>.
 
 =head1 BUGS
 
